@@ -30,7 +30,7 @@ require_once($CFG->dirroot . '/enrol/externallib.php');
  * @license    http://www.gnu.org/copyleft/gpl.html GNU GPL v3 or later
  * @since Moodle 2.4
  */
-class core_enrol_external_testcase extends externallib_advanced_testcase {
+class core_enrol_externallib_testcase extends externallib_advanced_testcase {
 
     /**
      * Test get_enrolled_users
@@ -210,103 +210,70 @@ class core_enrol_external_testcase extends externallib_advanced_testcase {
         $this->assertEquals(1, count($expecteduserlist));
         $this->assertEquals($student2->id, $expecteduser['id']);
     }
-}
-
-/**
- * Role external PHPunit tests
- *
- * @package    core_enrol
- * @category   external
- * @copyright  2012 Jerome Mouneyrac
- * @license    http://www.gnu.org/copyleft/gpl.html GNU GPL v3 or later
- * @since Moodle 2.4
- */
-class core_role_external_testcase extends externallib_advanced_testcase {
 
     /**
-     * Tests set up
+     * Test get_course_enrolment_methods
      */
-    protected function setUp() {
-        global $CFG;
-        require_once($CFG->dirroot . '/enrol/externallib.php');
-    }
-
-    /**
-     * Test assign_roles
-     */
-    public function test_assign_roles() {
-        global $USER;
+    public function test_get_course_enrolment_methods() {
+        global $DB;
 
         $this->resetAfterTest(true);
 
-        $course = self::getDataGenerator()->create_course();
+        // Get enrolment plugins.
+        $selfplugin = enrol_get_plugin('self');
+        $this->assertNotEmpty($selfplugin);
+        $manualplugin = enrol_get_plugin('manual');
+        $this->assertNotEmpty($manualplugin);
 
-        // Set the required capabilities by the external function.
-        $context = context_course::instance($course->id);
-        $roleid = $this->assignUserCapability('moodle/role:assign', $context->id);
-        $this->assignUserCapability('moodle/course:view', $context->id, $roleid);
+        $studentrole = $DB->get_record('role', array('shortname'=>'student'));
+        $this->assertNotEmpty($studentrole);
 
-        // Add manager role to $USER.
-        // So $USER is allowed to assign 'manager', 'editingteacher', 'teacher' and 'student'.
-        role_assign(1, $USER->id, context_system::instance()->id);
+        $course1 = self::getDataGenerator()->create_course();
+        $course2 = self::getDataGenerator()->create_course();
 
-        // Check the teacher role has not been assigned to $USER.
-        $users = get_role_users(3, $context);
-        $this->assertEquals(count($users), 0);
+        // Add enrolment methods for course.
+        $instanceid1 = $selfplugin->add_instance($course1, array('status' => ENROL_INSTANCE_ENABLED,
+                                                                'name' => 'Test instance 1',
+                                                                'customint6' => 1,
+                                                                'roleid' => $studentrole->id));
+        $instanceid2 = $selfplugin->add_instance($course1, array('status' => ENROL_INSTANCE_DISABLED,
+                                                                'name' => 'Test instance 2',
+                                                                'roleid' => $studentrole->id));
 
-        // Call the external function. Assign teacher role to $USER.
-        core_role_external::assign_roles(array(
-            array('roleid' => 3, 'userid' => $USER->id, 'contextid' => $context->id)));
+        $instanceid3 = $manualplugin->add_instance($course1, array('status' => ENROL_INSTANCE_ENABLED,
+                                                                'name' => 'Test instance 3'));
 
-        // Check the role has been assigned.
-        $users = get_role_users(3, $context);
-        $this->assertEquals(count($users), 1);
+        $enrolmentmethods = $DB->get_records('enrol', array('courseid' => $course1->id, 'status' => ENROL_INSTANCE_ENABLED));
+        $this->assertCount(2, $enrolmentmethods);
 
-        // Call without required capability.
-        $this->unassignUserCapability('moodle/role:assign', $context->id, $roleid);
-        $this->setExpectedException('moodle_exception');
-        $categories = core_role_external::assign_roles(
-            array('roleid' => 3, 'userid' => $USER->id, 'contextid' => $context->id));
-    }
+        // Check if information is returned.
+        $enrolmentmethods = core_enrol_external::get_course_enrolment_methods($course1->id);
+        $enrolmentmethods = external_api::clean_returnvalue(core_enrol_external::get_course_enrolment_methods_returns(),
+                                                            $enrolmentmethods);
+        // Enrolment information is currently returned by self enrolment plugin, so count == 1.
+        // This should be changed as we implement get_enrol_info() for other enrolment plugins.
+        $this->assertCount(1, $enrolmentmethods);
 
-    /**
-     * Test unassign_roles
-     */
-    public function test_unassign_roles() {
-        global $USER;
+        $enrolmentmethod = $enrolmentmethods[0];
+        $this->assertEquals($course1->id, $enrolmentmethod['courseid']);
+        $this->assertEquals('self', $enrolmentmethod['type']);
+        $this->assertTrue($enrolmentmethod['status']);
+        $this->assertFalse(isset($enrolmentmethod['wsfunction']));
 
-        $this->resetAfterTest(true);
+        $instanceid4 = $selfplugin->add_instance($course2, array('status' => ENROL_INSTANCE_ENABLED,
+                                                                'name' => 'Test instance 4',
+                                                                'roleid' => $studentrole->id,
+                                                                'customint6' => 1,
+                                                                'password' => 'test'));
+        $enrolmentmethods = core_enrol_external::get_course_enrolment_methods($course2->id);
+        $enrolmentmethods = external_api::clean_returnvalue(core_enrol_external::get_course_enrolment_methods_returns(),
+                                                            $enrolmentmethods);
+        $this->assertCount(1, $enrolmentmethods);
 
-        $course = self::getDataGenerator()->create_course();
-
-        // Set the required capabilities by the external function.
-        $context = context_course::instance($course->id);
-        $roleid = $this->assignUserCapability('moodle/role:assign', $context->id);
-        $this->assignUserCapability('moodle/course:view', $context->id, $roleid);
-
-        // Add manager role to $USER.
-        // So $USER is allowed to assign 'manager', 'editingteacher', 'teacher' and 'student'.
-        role_assign(1, $USER->id, context_system::instance()->id);
-
-        // Add teacher role to $USER on course context.
-        role_assign(3, $USER->id, $context->id);
-
-        // Check the teacher role has been assigned to $USER on course context.
-        $users = get_role_users(3, $context);
-        $this->assertEquals(count($users), 1);
-
-        // Call the external function. Assign teacher role to $USER.
-        core_role_external::unassign_roles(array(
-            array('roleid' => 3, 'userid' => $USER->id, 'contextid' => $context->id)));
-
-        // Check the role has been unassigned on course context.
-        $users = get_role_users(3, $context);
-        $this->assertEquals(count($users), 0);
-
-        // Call without required capability.
-        $this->unassignUserCapability('moodle/role:assign', $context->id, $roleid);
-        $this->setExpectedException('moodle_exception');
-        $categories = core_role_external::unassign_roles(
-            array('roleid' => 3, 'userid' => $USER->id, 'contextid' => $context->id));
+        $enrolmentmethod = $enrolmentmethods[0];
+        $this->assertEquals($course2->id, $enrolmentmethod['courseid']);
+        $this->assertEquals('self', $enrolmentmethod['type']);
+        $this->assertTrue($enrolmentmethod['status']);
+        $this->assertEquals('enrol_self_get_instance_info', $enrolmentmethod['wsfunction']);
     }
 }
