@@ -30,6 +30,7 @@ $string['annually'] = 'Annually';
 $string['calendar'] = 'Calendar';
 $string['calendarheading'] = '{$a} Calendar';
 $string['calendarpreferences'] = 'Calendar preferences';
+$string['calendartypes'] = 'Calendar types';
 $string['calendarurl'] = 'Calendar URL: {$a}';
 $string['clickhide'] = 'click to hide';
 $string['clickshow'] = 'click to show';
@@ -45,13 +46,13 @@ $string['courseevents'] = 'Course events';
 $string['courses'] = 'Courses';
 $string['customexport'] = 'Custom range ({$a->timestart} - {$a->timeend})';
 $string['daily'] = 'Daily';
-$string['dayview'] = 'Day view';
+$string['dayviewfor'] = 'Day view for:';
 $string['dayviewtitle'] = 'Day view: {$a}';
 $string['daywithnoevents'] = 'There are no events this day.';
 $string['default'] = 'Default';
 $string['deleteevent'] = 'Delete event';
 $string['deleteevents'] = 'Delete events';
-$string['detailedmonthview'] = 'Detailed month view';
+$string['detailedmonthviewfor'] = 'Detailed month view for:';
 $string['detailedmonthviewtitle'] = 'Detailed month view: {$a}';
 $string['durationminutes'] = 'Duration in minutes';
 $string['durationnone'] = 'Without duration';
@@ -68,6 +69,9 @@ $string['errorinvalidicalurl'] = 'The given iCal URL is invalid.';
 $string['errornodescription'] = 'Description is required';
 $string['errornoeventname'] = 'Name is required';
 $string['errorrequiredurlorfile'] = 'Either a URL or a file is required to import a calendar.';
+$string['errorrrule'] = 'The passed rrule seems incorrect';
+$string['errorrrulefreq'] = 'The rrule has an invalid frequency parameter';
+$string['errorrruleday'] = 'The rrule has an invalid day parameter';
 $string['eventdate'] = 'Date';
 $string['eventdescription'] = 'Description';
 $string['eventduration'] = 'Duration';
@@ -87,6 +91,9 @@ $string['eventsrelatedtocourses'] = 'Events related to courses';
 $string['eventstarttime'] = 'Start time';
 $string['eventtime'] = 'Time';
 $string['eventview'] = 'Event details';
+$string['eventcalendareventcreated'] = 'Calendar event created';
+$string['eventcalendareventupdated'] = 'Calendar event updated';
+$string['eventcalendareventdeleted'] = 'Calendar event deleted';
 $string['expired'] = 'Expired';
 $string['explain_site_timeformat'] = 'You can choose to see times in either 12 or 24 hour format for the whole site. If you choose "default", then the format will be automatically chosen according to the language you use in the site. This setting can be overridden by user preferences.';
 $string['export'] = 'Export';
@@ -198,6 +205,7 @@ $string['typegroup'] = 'Group event';
 $string['typesite'] = 'Site event';
 $string['typeuser'] = 'User event';
 $string['upcomingevents'] = 'Upcoming events';
+$string['upcomingeventsfor'] = 'Upcoming events for:';
 $string['urlforical'] = 'URL for iCalendar export, for subscribing to calendar';
 $string['user'] = 'User';
 $string['userevent'] = 'User event';
