@@ -18,8 +18,7 @@
 /**
  * Moodle renderer used to display special elements of the lesson module
  *
- * @package    mod
- * @subpackage lesson
+ * @package mod_lesson
  * @copyright  2009 Sam Hemelryk
  * @license    http://www.gnu.org/copyleft/gpl.html GNU GPL v3 or later
  **/
@@ -30,20 +29,25 @@ class mod_lesson_renderer extends plugin_renderer_base {
     /**
      * Returns the header for the lesson module
      *
-     * @param lesson $lesson
-     * @param string $currenttab
-     * @param bool $extraeditbuttons
-     * @param int $lessonpageid
+     * @param lesson $lesson a lesson object.
+     * @param string $currenttab current tab that is shown.
+     * @param bool   $extraeditbuttons if extra edit buttons should be displayed.
+     * @param int    $lessonpageid id of the lesson page that needs to be displayed.
+     * @param string $extrapagetitle String to appent to the page title.
      * @return string
      */
-    public function header($lesson, $cm, $currenttab = '', $extraeditbuttons = false, $lessonpageid = null) {
+    public function header($lesson, $cm, $currenttab = '', $extraeditbuttons = false, $lessonpageid = null, $extrapagetitle = null) {
         global $CFG;
 
         $activityname = format_string($lesson->name, true, $lesson->course);
-        $title = $this->page->course->shortname.": ".$activityname;
+        if (empty($extrapagetitle)) {
+            $title = $this->page->course->shortname.": ".$activityname;
+        } else {
+            $title = $this->page->course->shortname.": ".$activityname.": ".$extrapagetitle;
+        }
 
         // Build the buttons
-        $context = get_context_instance(CONTEXT_MODULE, $cm->id);
+        $context = context_module::instance($cm->id);
 
     /// Header setup
         $this->page->set_title($title);
@@ -166,6 +170,7 @@ class mod_lesson_renderer extends plugin_renderer_base {
 
         $yeslink = html_writer::link(new moodle_url('/mod/lesson/view.php', array('id'=>$this->page->cm->id, 'pageid'=>$lastpageseenid, 'startlastseen'=>'yes')), get_string('yes'));
         $output .= html_writer::tag('span', $yeslink, array('class'=>'lessonbutton standardbutton'));
+        $output .= '&nbsp;';
 
         $nolink = html_writer::link(new moodle_url('/mod/lesson/view.php', array('id'=>$this->page->cm->id, 'pageid'=>$lesson->firstpageid, 'startlastseen'=>'no')), get_string('no'));
         $output .= html_writer::tag('span', $nolink, array('class'=>'lessonbutton standardbutton'));
@@ -214,12 +219,17 @@ class mod_lesson_renderer extends plugin_renderer_base {
         $table->width = '80%';
         $table->data = array();
 
-        $canedit = has_capability('mod/lesson:edit', get_context_instance(CONTEXT_MODULE, $this->page->cm->id));
+        $canedit = has_capability('mod/lesson:edit', context_module::instance($this->page->cm->id));
 
         while ($pageid != 0) {
             $page = $lesson->load_page($pageid);
             $data = array();
-            $data[] = "<a href=\"$CFG->wwwroot/mod/lesson/edit.php?id=".$this->page->cm->id."&amp;mode=single&amp;pageid=".$page->id."\">".format_string($page->title,true).'</a>';
+            $url = new moodle_url('/mod/lesson/edit.php', array(
+                'id'     => $this->page->cm->id,
+                'mode'   => 'single',
+                'pageid' => $page->id
+            ));
+            $data[] = html_writer::link($url, format_string($page->title, true), array('id' => 'lesson-' . $page->id));
             $data[] = $qtypes[$page->qtype];
             $data[] = implode("<br />\n", $page->jumps);
             if ($canedit) {
@@ -249,7 +259,7 @@ class mod_lesson_renderer extends plugin_renderer_base {
         $manager = lesson_page_type_manager::get($lesson);
         $qtypes = $manager->get_page_type_strings();
         $npages = count($lesson->load_all_pages());
-        $canedit = has_capability('mod/lesson:edit', get_context_instance(CONTEXT_MODULE, $this->page->cm->id));
+        $canedit = has_capability('mod/lesson:edit', context_module::instance($this->page->cm->id));
 
         $content = '';
         if ($canedit) {
@@ -269,6 +279,7 @@ class mod_lesson_renderer extends plugin_renderer_base {
             $pagetable->cellspacing = 0;
             $pagetable->cellpadding = '5px';
             $pagetable->data = array();
+            $pagetable->id = 'lesson-' . $pageid;
 
             $pageheading = new html_table_cell();
 
@@ -295,7 +306,9 @@ class mod_lesson_renderer extends plugin_renderer_base {
 
             $pagetable = $page->display_answers($pagetable);
 
+            $content .= html_writer::start_tag('div', array('class' => 'no-overflow'));
             $content .= html_writer::table($pagetable);
+            $content .= html_writer::end_tag('div');
 
             if ($canedit) {
                 $content .= $this->add_page_links($lesson, $pageid);
@@ -363,9 +376,6 @@ class mod_lesson_renderer extends plugin_renderer_base {
         $importquestionsurl = new moodle_url('/mod/lesson/import.php',array('id'=>$this->page->cm->id, 'pageid'=>$prevpageid));
         $links[] = html_writer::link($importquestionsurl, get_string('importquestions', 'lesson'));
 
-        $importppturl = new moodle_url('/mod/lesson/importppt.php',array('id'=>$this->page->cm->id, 'pageid'=>$prevpageid));
-        $links[] = html_writer::link($importppturl, get_string('importppt', 'lesson'));
-
         $manager = lesson_page_type_manager::get($lesson);
         foreach ($manager->get_add_page_type_links($prevpageid) as $link) {
             $link['addurl']->param('firstpage', 1);
@@ -392,17 +402,27 @@ class mod_lesson_renderer extends plugin_renderer_base {
         $actions = array();
 
         if ($printmove) {
-            $printmovehtml = new moodle_url('/mod/lesson/lesson.php', array('id'=>$this->page->cm->id, 'action'=>'move', 'pageid'=>$page->id, 'sesskey'=>sesskey()));
-            $actions[] = html_writer::link($printmovehtml, '<img src="'.$this->output->pix_url('t/move').'" class="iconsmall" alt="'.get_string('move').'" />');
+            $url = new moodle_url('/mod/lesson/lesson.php',
+                    array('id' => $this->page->cm->id, 'action' => 'move', 'pageid' => $page->id, 'sesskey' => sesskey()));
+            $label = get_string('movepagenamed', 'lesson', format_string($page->title));
+            $img = html_writer::img($this->output->pix_url('t/move'), $label, array('class' => 'iconsmall'));
+            $actions[] = html_writer::link($url, $img, array('title' => $label));
         }
-        $url = new moodle_url('/mod/lesson/editpage.php', array('id'=>$this->page->cm->id, 'pageid'=>$page->id, 'edit'=>1));
-        $actions[] = html_writer::link($url, '<img src="'.$this->output->pix_url('t/edit').'" class="iconsmall" alt="'.get_string('update').'" />');
+        $url = new moodle_url('/mod/lesson/editpage.php', array('id' => $this->page->cm->id, 'pageid' => $page->id, 'edit' => 1));
+        $label = get_string('updatepagenamed', 'lesson', format_string($page->title));
+        $img = html_writer::img($this->output->pix_url('t/edit'), $label, array('class' => 'iconsmall'));
+        $actions[] = html_writer::link($url, $img, array('title' => $label));
 
-        $url = new moodle_url('/mod/lesson/view.php', array('id'=>$this->page->cm->id, 'pageid'=>$page->id));
-        $actions[] = html_writer::link($url, '<img src="'.$this->output->pix_url('t/preview').'" class="iconsmall" alt="'.get_string('preview').'" />');
+        $url = new moodle_url('/mod/lesson/view.php', array('id' => $this->page->cm->id, 'pageid' => $page->id));
+        $label = get_string('previewpagenamed', 'lesson', format_string($page->title));
+        $img = html_writer::img($this->output->pix_url('t/preview'), $label, array('class' => 'iconsmall'));
+        $actions[] = html_writer::link($url, $img, array('title' => $label));
 
-        $url = new moodle_url('/mod/lesson/lesson.php', array('id'=>$this->page->cm->id, 'action'=>'confirmdelete', 'pageid'=>$page->id, 'sesskey'=>sesskey()));
-        $actions[] = html_writer::link($url, '<img src="'.$this->output->pix_url('t/delete').'" class="iconsmall" alt="'.get_string('delete').'" />');
+        $url = new moodle_url('/mod/lesson/lesson.php',
+                array('id' => $this->page->cm->id, 'action' => 'confirmdelete', 'pageid' => $page->id, 'sesskey' => sesskey()));
+        $label = get_string('deletepagenamed', 'lesson', format_string($page->title));
+        $img = html_writer::img($this->output->pix_url('t/delete'), $label, array('class' => 'iconsmall'));
+        $actions[] = html_writer::link($url, $img, array('title' => $label));
 
         if ($printaddpage) {
             $options = array();
@@ -451,7 +471,7 @@ class mod_lesson_renderer extends plugin_renderer_base {
     public function ongoing_score(lesson $lesson) {
         global $USER, $DB;
 
-        $context = get_context_instance(CONTEXT_MODULE, $this->page->cm->id);
+        $context = context_module::instance($this->page->cm->id);
         if (has_capability('mod/lesson:manage', $context)) {
             return $this->output->box(get_string('teacherongoingwarning', 'lesson'), "ongoing center");
         } else {
@@ -482,7 +502,7 @@ class mod_lesson_renderer extends plugin_renderer_base {
     public function progress_bar(lesson $lesson) {
         global $CFG, $USER, $DB;
 
-        $context = get_context_instance(CONTEXT_MODULE, $this->page->cm->id);
+        $context = context_module::instance($this->page->cm->id);
 
         // lesson setting to turn progress bar on or off
         if (!$lesson->progressbar) {
@@ -509,15 +529,20 @@ class mod_lesson_renderer extends plugin_renderer_base {
                 $ntries = 0;  // may not be necessary
             }
 
-
             $viewedpageids = array();
-            if ($attempts = $lesson->get_attempts($ntries, true)) {
-                $viewedpageids = array_merge($viewedpageids, array_keys($attempts));
+            if ($attempts = $lesson->get_attempts($ntries, false)) {
+                foreach($attempts as $attempt) {
+                    $viewedpageids[$attempt->pageid] = $attempt;
+                }
             }
 
+            $viewedbranches = array();
             // collect all of the branch tables viewed
-            if ($viewedbranches = $DB->get_records("lesson_branch", array ("lessonid"=>$lesson->id, "userid"=>$USER->id, "retry"=>$ntries), 'timeseen DESC', 'id, pageid')) {
-                $viewedpageids = array_merge($viewedpageids, array_keys($viewedbranches));
+            if ($branches = $DB->get_records("lesson_branch", array ("lessonid"=>$lesson->id, "userid"=>$USER->id, "retry"=>$ntries), 'timeseen ASC', 'id, pageid')) {
+                foreach($branches as $branch) {
+                    $viewedbranches[$branch->pageid] = $branch;
+                }
+                $viewedpageids = array_merge($viewedpageids, $viewedbranches);
             }
 
             // Filter out the following pages:
@@ -538,20 +563,10 @@ class mod_lesson_renderer extends plugin_renderer_base {
         }
 
         // print out the Progress Bar.  Attempted to put as much as possible in the style sheets.
-        $cells = array();
-        if ($progress != 0) {  // some browsers do not repsect the 0 width.
-            $cells[0] = new html_table_cell();
-            $cells[0]->style = 'width:'.$progress.'%';
-            $cells[0]->attributes['class'] = 'progress_bar_completed';
-            $cells[0]->text = ' ';
-        }
-        $cells[] = '<div class="progress_bar_token"></div>';
+        $content = '<br />' . html_writer::tag('div', $progress . '%', array('class' => 'progress_bar_completed', 'style' => 'width: '. $progress . '%;'));
+        $printprogress = html_writer::tag('div', get_string('progresscompleted', 'lesson', $progress) . $content, array('class' => 'progress_bar'));
 
-        $table = new html_table();
-        $table->attributes['class'] = 'progress_bar_table';
-        $table->data = array(new html_table_row($cells));
-
-        return $this->output->box(html_writer::table($table), 'progress_bar');
+        return $this->output->box($printprogress, 'progress_bar');
     }
 
     /**
@@ -561,14 +576,17 @@ class mod_lesson_renderer extends plugin_renderer_base {
     public function slideshow_start(lesson $lesson) {
         $attributes = array();
         $attributes['class'] = 'slideshow';
-        $attributes['style'] = 'background-color:'.$lesson->bgcolor.';height:'.$lesson->height.'px;width:'.$lesson->width.'px;';
+        $attributes['style'] = 'background-color:'.$lesson->properties()->bgcolor.';height:'.
+                $lesson->properties()->height.'px;width:'.$lesson->properties()->width.'px;';
         $output = html_writer::start_tag('div', $attributes);
+        return $output;
     }
     /**
      * Returns HTML to show the end of a slideshow
      */
     public function slideshow_end() {
         $output = html_writer::end_tag('div');
+        return $output;
     }
     /**
      * Returns a P tag containing contents
@@ -581,6 +599,7 @@ class mod_lesson_renderer extends plugin_renderer_base {
             $attributes['class'] = $class;
         }
         $output = html_writer::tag('p', $contents, $attributes);
+        return $output;
     }
     /**
      * Returns HTML to display add_highscores_form
