@@ -959,7 +959,7 @@ function scorm_pluginfile($course, $cm, $context, $filearea, $args, $forcedownlo
     $lifetime = null;
 
     if ($filearea === 'content') {
-        $revision = (int)array_shift($args); // prevents caching problems - ignored here
+        $revision = (int)array_shift($args); // Prevents caching problems - ignored here.
         $relativepath = implode('/', $args);
         $fullpath = "/$context->id/mod_scorm/content/0/$relativepath";
         // TODO: add any other access restrictions here if needed!
@@ -968,6 +968,7 @@ function scorm_pluginfile($course, $cm, $context, $filearea, $args, $forcedownlo
         if (!has_capability('moodle/course:manageactivities', $context)) {
             return false;
         }
+        $revision = (int)array_shift($args); // Prevents caching problems - ignored here.
         $relativepath = implode('/', $args);
         $fullpath = "/$context->id/mod_scorm/package/0/$relativepath";
         $lifetime = 0; // no caching here
@@ -1445,7 +1446,7 @@ function scorm_check_mode($scorm, &$newattempt, &$attempt, $userid, &$mode) {
     if ($incomplete === true) {
         // The option to start a new attempt should never have been presented. Force false.
         $newattempt = 'off';
-    } else if (($attempt !== '1') && !empty($scorm->forcenewattempt)) {
+    } else if (!empty($scorm->forcenewattempt)) {
         // A new attempt should be forced for already completed attempts.
         $newattempt = 'on';
     }
